"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadMathJax = exports.getMathJax = exports.DEFAULT_OPTIONS = exports.DEFAULT_SCRIPT = void 0;

var _loadScript = _interopRequireDefault(require("load-script"));

var DEFAULT_SCRIPT = process.env.MATHJAX_CDN || 'https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.3/MathJax.js';
exports.DEFAULT_SCRIPT = DEFAULT_SCRIPT;
var DEFAULT_OPTIONS = {
  TeX: {
    extensions: ['AMSmath.js', 'AMSsymbols.js']
  },
  extensions: ['tex2jax.js'],
  showProcessingMessages: false,
  jax: ['input/TeX', 'output/HTML-CSS'],
  messageStyle: 'none',
  showMathMenu: false,
  showMathMenuMSIE: false,
  tex2jax: {
    processEnvironments: true,
    inlineMath: [['$', '$'], ['\\(', '\\)']],
    displayMath: [['$$', '$$'], ['\\[', '\\]']],
    preview: 'none',
    processEscapes: true
  },
  'HTML-CSS': {
    linebreaks: {
      automatic: true,
      width: 'container'
    }
  }
};
exports.DEFAULT_OPTIONS = DEFAULT_OPTIONS;

var getMathJax = function getMathJax() {
  return typeof MathJax === 'undefined' ? undefined : MathJax;
};

exports.getMathJax = getMathJax;

var loadMathJax = function loadMathJax() {
  var callback = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : function () {};
  var script = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEFAULT_SCRIPT;
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : DEFAULT_OPTIONS;

  var onLoad = function onLoad() {
    MathJax.Hub.Config(options);
    callback();
  };

  if (!script) {
    return onLoad();
  }

  (0, _loadScript["default"])(script, onLoad);
};

exports.loadMathJax = loadMathJax;